# Functions shared by op5-backup & op5-restore

# Return true (0) if we're invoked as op5-restore, otherwise false.
function is_restore()
{
	[ -n "${RESTORE:-}" ]
}


function log()
{
	case ${2} in
		notice)
			LOGPRIO="cron.notice"
			;;
		debug)
			LOGPRIO="cron.debug"
			;;
		warning)
			LOGPRIO="cron.warning"
			;;
		error)
			LOGPRIO="cron.err"
			;;
		*)
			LOGPRIO="cron.info"
			;;
	esac

	message="$1"

	if [ "${2}" != "" ] ; then
		severity=$(echo $2|tr "[:lower:]" "[:upper:]")
	else
		severity="INFO"
	fi
	if is_restore; then
		local log_basename=restore
		local syslog_tag=op5restore
	else
		local log_basename=backup
		local syslog_tag=op5backup
	fi

	prefix="$(date +'%Y-%m-%d %H:%M:%S') ${severity} -"
	[ -d "$LOGDIR" ] || mkdir -p "$LOGDIR"
	if [ "${EXEC_IN_FG}" -eq 1 ] ; then
		echo "${prefix} ${message}"
	fi
	echo "${prefix} ${message}" >> "$LOGDIR/$log_basename-$TIMESTAMP.log"
	logger -p $LOGPRIO -t $syslog_tag "${severity} - ${message}"
}

function read_os_release()
{
	local key file
	key="${1:-}"
	file="${2:-/etc/os-release}"
	source "$file"
	if [ -n "$(eval echo \$$key)" ]; then
		eval echo \$$key
		return 0
	fi
	echo "error: read_os_release: no key named '$key'" >&2
	return 1
}
